@@ -9,17 +9,14 @@ const banner = `
    ___  _______ __ __ (_) _/_ __
   / _ \/ __/ _ \\ \ // / _/ // /
  / .__/_/  \___/_\_\/_/_/ \_, / 
-/_/                      /___/	v0.0.7
+/_/                      /___/	v0.0.8
 `
 
 // Version is the current version
-const Version = `0.0.7`
+const Version = `0.0.8`
 
 // showBanner is used to show the banner to the user
 func showBanner() {
 	gologger.Print().Msgf("%s\n", banner)
 	gologger.Print().Msgf("\t\tprojectdiscovery.io\n\n")
-
-	gologger.Print().Msgf("Use with caution. You are responsible for your actions\n")
-	gologger.Print().Msgf("Developers assume no liability and are not responsible for any misuse or damage.\n")
 }
