@@ -24,7 +24,7 @@ const (
 )
 
 type OptionsLogger struct {
-	Verbose      bool
+	Verbosity    types.Verbosity
 	OutputFolder string
 	DumpRequest  bool
 	DumpResponse bool
@@ -49,10 +49,7 @@ func NewLogger(options *OptionsLogger) *Logger {
 		asyncqueue: make(chan types.OutputData, 1000),
 	}
 	if options.Elastic.Addr != "" {
-		store, err := elastic.New(&elastic.Options{
-			Addr:      options.Elastic.Addr,
-			IndexName: options.Elastic.IndexName,
-		})
+		store, err := elastic.New(options.Elastic)
 		if err != nil {
 			gologger.Warning().Msgf("Error while creating elastic logger: %s", err)
 		} else {
@@ -135,7 +132,7 @@ func (l *Logger) LogRequest(req *http.Request, userdata types.UserData) error {
 		l.asyncqueue <- types.OutputData{Data: reqdump, Userdata: userdata}
 	}
 
-	if l.options.Verbose {
+	if l.options.Verbosity >= types.VerbosityVeryVerbose {
 		contentType := req.Header.Get("Content-Type")
 		b, _ := ioutil.ReadAll(req.Body)
 		if isASCIICheckRequired(contentType) && !govalidator.IsPrintableASCII(string(b)) {
@@ -166,7 +163,7 @@ func (l *Logger) LogResponse(resp *http.Response, userdata types.UserData) error
 	if l.options.OutputFolder != "" || l.options.Kafka.Addr != "" || l.options.Elastic.Addr != "" {
 		l.asyncqueue <- types.OutputData{Data: respdump, Userdata: userdata}
 	}
-	if l.options.Verbose {
+	if l.options.Verbosity >= types.VerbosityVeryVerbose {
 		contentType := resp.Header.Get("Content-Type")
 		bodyBytes := bytes.TrimPrefix(respdump, respdumpNoBody)
 		if isASCIICheckRequired(contentType) && !govalidator.IsPrintableASCII(string(bodyBytes)) {
